@@ -22,10 +22,8 @@
 #
 
 PACKAGE_NAME = 'imgbased'
-PACKAGE_VERSION = '0.9.6'
-REVISION = 'git60d0247'
-RELEASE = '0.201701270841'
+PACKAGE_VERSION = '0.9.14'
 
 
 def version():
-    return "%s-%s-%s%s" % (PACKAGE_NAME, PACKAGE_VERSION, RELEASE, REVISION)
+    return "%s-%s" % (PACKAGE_NAME, PACKAGE_VERSION)
